@@ -5,7 +5,7 @@ from aiokafka import AIOKafkaProducer
 
 from async_tools import AsyncOnStart, AsyncOnStop
 
-from notification_server_connector.models.notification import Notification
+from notification_server_connector.models.notification import Notification, SourceTypes
 from notification_server_connector.utils.abstract_encoder import AbstractEncoder
 
 
@@ -54,7 +54,9 @@ class NotificationConnector(AsyncOnStart, AsyncOnStop):
             logger.error(f'write to kafka channel "{self._config.topic}" failed, error: {exc}')
             return False
 
-    async def mark_notification_as_read_internal(self, user_id: int, source_type: str, target_ids: list[int]) -> None:
+    async def mark_notification_as_read_internal(
+        self, user_id: int, source_type: SourceTypes, target_ids: list[int]
+    ) -> None:
         logger.debug(f'mark notification as read for source: {source_type}, targe: {target_ids}')
         async with self._http_client.post(
             f'{self._config.url}/v1/mark_notification_as_read_internal',
